/*
** fallback.c
**
**	This file only defines the 'fallback_resources' to be
**	passed to the XtAppInitialize of the demo programs.
**
**	This file is directly *included* into each demo program.
**	(Not compiled separately)
*/

static char *fallback_resources[] =
    {
	"*XeText.fonts:14 -*-times=iso8859-1,-",
	"*XeTextEd.fonts:14 -*-times=iso8859-1,-",
	"*XeRaster.translations: #augment\\nCtrl<Btn3Up>:notify(MENU)\\n",
	"*XeVideo.translations: #augment\\nCtrl<Btn3Up>:notify(MENU)\\n",
	"*XeAudio.translations: #augment\\nCtrl<Btn3Up>:notify(MENU)\\n",
	"*XeText.translations: #augment\\nCtrl<Btn3Up>:notify(MENU)\\n",
	"*XeFrame.translations: #augment\\nCtrl<Btn3Up>:notify(MENU)\\n",
	"*XeTextEd.displayCaret:False",
	"*XeTextEd.translations: #override\\n<FocusIn>:display-caret(on)\\n<FocusOut>:display-caret(off)\\nCtrl<Btn3Up>:notify(MENU)\\n",
	"*FrameBorder:solid,1,1",
	"*FrameSeparation:1",
	"*FrameOffset:1",
	"*FrameDimension:rule-b",
	"*panel.middle.FrameBorder:invisible",
	"*panel.middle.pane.vertical:max",
	"*panel.top.horizontal:max",
	"*panel.bottom.horizontal:max",
	"*panel.middle.layoutPath:0",
	"*panel.middle.menuPanel.vertical:max",
	"*labelBox.FrameBorder:invisible",
	"*inputBox.FrameBorder:invisible",
	"*inputBox.horizontal:max",
	"*inputArea.horizontal:max,60",
	"*inputPrompt.FrameBorder:invisible",
	"*toggleBox.FrameBorder:invisible",
	"*mainWindow.layoutPath:270",
	"*workArea.FrameDimension:max",
	"*menuPanel.layoutPath:0",
	NULL,
    };






